@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2019  The Software Heritage developers
+# Copyright (C) 2017-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -9,7 +9,7 @@ from io import BytesIO
 import uuid
 
 import attr
-from django.urls import reverse
+from django.urls import reverse_lazy as reverse
 import pytest
 from rest_framework import status
 
